import { AbstractControl, FormBuilder, FormControl, FormGroup, AbstractControlOptions, FormArray } from '@angular/forms';
import { Observable } from 'rxjs';
export declare type FormGroupControlsOf<T> = {
    [P in keyof T]: FormControl | FormGroup | FormArray;
};
export interface FormGroupTypeSafe<T> extends FormGroup {
    readonly value: T;
    readonly valueChanges: Observable<T>;
    getSafe(propertyFunction: (typeVal: T) => any): AbstractControl | null;
    setControlSafe(propertyFunction: (typeVal: T) => any, control: AbstractControl): void;
    setValue(value: T, options?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    patchValue(value: Partial<T>, options?: Object): void;
}
export interface FormControlTypeSafe<T> extends FormControl {
    value: T | undefined;
}
export declare const generateGetSafeFunction: <T extends unknown>(gr: FormGroupTypeSafe<T>) => (propertyFunction: (typeVal: T) => any) => AbstractControl;
export declare const generateSetControlSafeFunction: <T extends unknown>(gr: FormGroupTypeSafe<T>) => (propertyFunction: (typeVal: T) => any, control: AbstractControl) => void;
export declare class FormBuilderTypeSafe extends FormBuilder {
    group<T>(controlsConfig: FormGroupControlsOf<T>, options?: AbstractControlOptions | {
        [key: string]: any;
    } | null): FormGroupTypeSafe<T>;
}
